package _type

import "github.com/gogo/googleapis/google/geo/type"

Index

Variables

var (
	ErrInvalidLengthViewport        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowViewport          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupViewport = fmt.Errorf("proto: unexpected end of group")
)

Types

type Viewport

type Viewport struct {
	// Required. The low point of the viewport.
	Low *_type.LatLng `protobuf:"bytes,1,opt,name=low,proto3" json:"low,omitempty"`
	// Required. The high point of the viewport.
	High                 *_type.LatLng `protobuf:"bytes,2,opt,name=high,proto3" json:"high,omitempty"`
	XXX_NoUnkeyedLiteral struct{}      `json:"-"`
	XXX_unrecognized     []byte        `json:"-"`
	XXX_sizecache        int32         `json:"-"`
}

A latitude-longitude viewport, represented as two diagonally opposite `low` and `high` points. A viewport is considered a closed region, i.e. it includes its boundary. The latitude bounds must range between -90 to 90 degrees inclusive, and the longitude bounds must range between -180 to 180 degrees inclusive. Various cases include:

Both `low` and `high` must be populated, and the represented box cannot be empty (as specified by the definitions above). An empty viewport will result in an error.

For example, this viewport fully encloses New York City:

{
    "low": {
        "latitude": 40.477398,
        "longitude": -74.259087
    },
    "high": {
        "latitude": 40.91618,
        "longitude": -73.70018
    }
}

func NewPopulatedViewport

func NewPopulatedViewport(r randyViewport, easy bool) *Viewport

func (*Viewport) Descriptor

func (*Viewport) Descriptor() ([]byte, []int)

func (*Viewport) Equal

func (this *Viewport) Equal(that interface{}) bool

func (*Viewport) GetHigh

func (m *Viewport) GetHigh() *_type.LatLng

func (*Viewport) GetLow

func (m *Viewport) GetLow() *_type.LatLng

func (*Viewport) GoString

func (this *Viewport) GoString() string

func (*Viewport) Marshal

func (m *Viewport) Marshal() (dAtA []byte, err error)

func (*Viewport) MarshalTo

func (m *Viewport) MarshalTo(dAtA []byte) (int, error)

func (*Viewport) MarshalToSizedBuffer

func (m *Viewport) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*Viewport) ProtoMessage

func (*Viewport) ProtoMessage()

func (*Viewport) Reset

func (m *Viewport) Reset()

func (*Viewport) Size

func (m *Viewport) Size() (n int)

func (*Viewport) String

func (this *Viewport) String() string

func (*Viewport) Unmarshal

func (m *Viewport) Unmarshal(dAtA []byte) error

func (*Viewport) XXX_DiscardUnknown

func (m *Viewport) XXX_DiscardUnknown()

func (*Viewport) XXX_Marshal

func (m *Viewport) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Viewport) XXX_Merge

func (m *Viewport) XXX_Merge(src proto.Message)

func (*Viewport) XXX_MessageName

func (*Viewport) XXX_MessageName() string

func (*Viewport) XXX_Size

func (m *Viewport) XXX_Size() int

func (*Viewport) XXX_Unmarshal

func (m *Viewport) XXX_Unmarshal(b []byte) error

Source Files

viewport.pb.go

Version
v1.4.1 (latest)
Published
Mar 10, 2021
Platform
linux/amd64
Imports
9 packages
Last checked
10 months ago

Tools for package owners.